from http import HTTPStatus
from typing import Any

import httpx

from peertube import errors
from peertube.client import AuthenticatedClient, Client
from peertube.models.get_jobs_job_type import GetJobsJobType
from peertube.models.get_jobs_response_200 import GetJobsResponse200
from peertube.models.get_jobs_state import GetJobsState
from peertube.types import UNSET, Response, Unset


def _get_kwargs(
    state: GetJobsState,
    *,
    job_type: Unset | GetJobsJobType = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_job_type: Unset | str = UNSET
    if not isinstance(job_type, Unset):
        json_job_type = job_type.value

    params["jobType"] = json_job_type

    params["start"] = start

    params["count"] = count

    params["sort"] = sort
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/api/v1/jobs/{state}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> GetJobsResponse200 | None:
    if response.status_code == 200:
        response_200 = GetJobsResponse200.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[GetJobsResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    state: GetJobsState,
    *,
    client: AuthenticatedClient,
    job_type: Unset | GetJobsJobType = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Response[GetJobsResponse200]:
    """List instance jobs


    Args:
        state (GetJobsState): Current state or status filter.
        job_type (Union[Unset, GetJobsJobType]): Parameter for job type.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetJobsResponse200]
    """

    kwargs = _get_kwargs(
        state=state, job_type=job_type, start=start, count=count, sort=sort
    )

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    state: GetJobsState,
    *,
    client: AuthenticatedClient,
    job_type: Unset | GetJobsJobType = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> GetJobsResponse200 | None:
    """List instance jobs


    Args:
        state (GetJobsState): Current state or status filter.
        job_type (Union[Unset, GetJobsJobType]): Parameter for job type.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetJobsResponse200
    """

    return sync_detailed(
        state=state,
        client=client,
        job_type=job_type,
        start=start,
        count=count,
        sort=sort,
    ).parsed


async def asyncio_detailed(
    state: GetJobsState,
    *,
    client: AuthenticatedClient,
    job_type: Unset | GetJobsJobType = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Response[GetJobsResponse200]:
    """List instance jobs


    Args:
        state (GetJobsState): Current state or status filter.
        job_type (Union[Unset, GetJobsJobType]): Parameter for job type.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetJobsResponse200]
    """

    kwargs = _get_kwargs(
        state=state, job_type=job_type, start=start, count=count, sort=sort
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    state: GetJobsState,
    *,
    client: AuthenticatedClient,
    job_type: Unset | GetJobsJobType = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> GetJobsResponse200 | None:
    """List instance jobs


    Args:
        state (GetJobsState): Current state or status filter.
        job_type (Union[Unset, GetJobsJobType]): Parameter for job type.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetJobsResponse200
    """

    return (
        await asyncio_detailed(
            state=state,
            client=client,
            job_type=job_type,
            start=start,
            count=count,
            sort=sort,
        )
    ).parsed



"""Tests for get_video_captions_content function."""

from peertube.api.video_captions.get_video_captions_content import (
    get_video_captions_content,
)
from peertube.client import Client
from peertube.models.get_video_captions_response_200 import GetVideoCaptionsResponse200
from peertube.models.video_caption import VideoCaption
from peertube.models.video_constant_string_language import VideoConstantStringLanguage


def test_get_captions_content_success(httpx_mock):
    """Test successful caption content retrieval."""
    # Create client
    client = Client(base_url="https://peertube.example.com")

    # Mock caption data
    language = VideoConstantStringLanguage(id="en", label="English")
    caption = VideoCaption(
        language=language, caption_path="/api/v1/videos/test-video/captions/en"
    )
    caption.additional_properties = {
        "fileUrl": "https://peertube.example.com/caption/en.vtt"
    }
    captions_response = GetVideoCaptionsResponse200(total=1, data=[caption])

    # Mock HTTP response for captions list
    httpx_mock.add_response(
        method="GET",
        url="https://peertube.example.com/api/v1/videos/test-video/captions",
        json=captions_response.to_dict(),
        status_code=200,
    )

    # Mock HTTP response for VTT content
    sample_vtt_content = """WEBVTT

00:00:00.000 --> 00:00:02.000
Hello world!

00:00:02.000 --> 00:00:04.000
This is a test caption.
"""
    httpx_mock.add_response(
        method="GET",
        url="https://peertube.example.com/caption/en.vtt",
        content=sample_vtt_content.encode("utf-8"),
        status_code=200,
    )

    # Test the function
    result = get_video_captions_content(client=client, id="test-video")

    assert result == sample_vtt_content



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.runner_job_admin import RunnerJobAdmin


T = TypeVar("T", bound="GetApiV1RunnersJobsResponse200")


@_attrs_define
class GetApiV1RunnersJobsResponse200:
    """Attributes:
    total (Union[Unset, int]):  Example: 1.
    data (Union[Unset, list['RunnerJobAdmin']]):
    """

    total: Unset | int = UNSET
    data: Unset | list["RunnerJobAdmin"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        total = self.total

        data: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.data, Unset):
            data = []
            for data_item_data in self.data:
                data_item = data_item_data.to_dict()
                data.append(data_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if total is not UNSET:
            field_dict["total"] = total
        if data is not UNSET:
            field_dict["data"] = data

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.runner_job_admin import RunnerJobAdmin

        d = dict(src_dict)
        total = d.pop("total", UNSET)

        data = []
        _data = d.pop("data", UNSET)
        for data_item_data in _data or []:
            data_item = RunnerJobAdmin.from_dict(data_item_data)

            data.append(data_item)

        get_api_v1_runners_jobs_response_200 = cls(total=total, data=data)

        get_api_v1_runners_jobs_response_200.additional_properties = d
        return get_api_v1_runners_jobs_response_200

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, cast
from uuid import UUID

import httpx

from peertube import errors
from peertube.client import AuthenticatedClient, Client
from peertube.types import UNSET, Response, Unset


def _get_kwargs(
    id: UUID | int | str, *, x_peertube_video_password: Unset | str = UNSET
) -> dict[str, Any]:
    headers: dict[str, Any] = {}
    if not isinstance(x_peertube_video_password, Unset):
        headers["x-peertube-video-password"] = x_peertube_video_password
    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/api/v1/videos/{id}/description",
    }

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> None | str:
    if response.status_code == 200:

        def _parse_response_200(data: object) -> None | str:
            if data is None:
                return data
            return cast("None | str", data)

        response_200 = _parse_response_200(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[None | str]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient | Client,
    x_peertube_video_password: Unset | str = UNSET,
) -> Response[None | str]:
    """Get complete video description


    Args:
        id (Union[UUID, int, str]): Unique identifier for the entity.
        x_peertube_video_password (Union[Unset, str]): Video-related parameter.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[None, str]]
    """

    kwargs = _get_kwargs(id=id, x_peertube_video_password=x_peertube_video_password)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient | Client,
    x_peertube_video_password: Unset | str = UNSET,
) -> None | str:
    """Get complete video description


    Args:
        id (Union[UUID, int, str]): Unique identifier for the entity.
        x_peertube_video_password (Union[Unset, str]): Video-related parameter.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[None, str]
    """

    return sync_detailed(
        id=id, client=client, x_peertube_video_password=x_peertube_video_password
    ).parsed


async def asyncio_detailed(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient | Client,
    x_peertube_video_password: Unset | str = UNSET,
) -> Response[None | str]:
    """Get complete video description


    Args:
        id (Union[UUID, int, str]): Unique identifier for the entity.
        x_peertube_video_password (Union[Unset, str]): Video-related parameter.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[None, str]]
    """

    kwargs = _get_kwargs(id=id, x_peertube_video_password=x_peertube_video_password)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient | Client,
    x_peertube_video_password: Unset | str = UNSET,
) -> None | str:
    """Get complete video description


    Args:
        id (Union[UUID, int, str]): Unique identifier for the entity.
        x_peertube_video_password (Union[Unset, str]): Video-related parameter.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[None, str]
    """

    return (
        await asyncio_detailed(
            id=id, client=client, x_peertube_video_password=x_peertube_video_password
        )
    ).parsed



"""Tests for get_playlists function."""

from peertube.api.video_playlists.get_playlists import sync


def test_get_playlists_success(httpx_mock, client):
    """Test successful retrieval of video playlists."""
    # Sample response data
    sample_data = {
        "total": 2,
        "data": [
            {
                "id": 1,
                "uuid": "9c9de5e8-0a1e-484a-b099-e80766180a6d",
                "displayName": "My Playlist 1",
                "description": "A test playlist",
            },
            {
                "id": 2,
                "uuid": "8b8ce5e7-0a1e-484a-b099-e80766180a6c",
                "displayName": "My Playlist 2",
                "description": "Another test playlist",
            },
        ],
    }

    # Mock HTTP response
    httpx_mock.add_response(
        method="GET",
        url="https://test.peertube.example/api/v1/video-playlists?count=15",
        status_code=200,
        json=sample_data,
    )

    # Test the function
    result = sync(client=client)

    assert result is not None
    assert result.total == 2
    assert result.data is not None
    assert len(result.data) == 2  # type: ignore[arg-type]
    assert result.data[0].id == 1  # type: ignore[attr-defined]
    assert result.data[0].display_name == "My Playlist 1"  # type: ignore[attr-defined]
    assert result.data[1].id == 2  # type: ignore[attr-defined]
    assert result.data[1].display_name == "My Playlist 2"  # type: ignore[attr-defined]



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.models.job_state import JobState
from peertube.models.job_type import JobType
from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.job_data import JobData
    from peertube.models.job_error import JobError


T = TypeVar("T", bound="Job")


@_attrs_define
class Job:
    """Attributes:
    id (Union[Unset, int]):  Example: 42.
    state (Union[Unset, JobState]):
    type_ (Union[Unset, JobType]):
    data (Union[Unset, JobData]):
    error (Union[Unset, JobError]):
    created_at (Union[Unset, datetime.datetime]):
    finished_on (Union[Unset, datetime.datetime]):
    processed_on (Union[Unset, datetime.datetime]):
    """

    id: Unset | int = UNSET
    state: Unset | JobState = UNSET
    type_: Unset | JobType = UNSET
    data: Union[Unset, "JobData"] = UNSET
    error: Union[Unset, "JobError"] = UNSET
    created_at: Unset | datetime.datetime = UNSET
    finished_on: Unset | datetime.datetime = UNSET
    processed_on: Unset | datetime.datetime = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        id = self.id

        state: Unset | str = UNSET
        if not isinstance(self.state, Unset):
            state = self.state.value

        type_: Unset | str = UNSET
        if not isinstance(self.type_, Unset):
            type_ = self.type_.value

        data: Unset | dict[str, Any] = UNSET
        if not isinstance(self.data, Unset):
            data = self.data.to_dict()

        error: Unset | dict[str, Any] = UNSET
        if not isinstance(self.error, Unset):
            error = self.error.to_dict()

        created_at: Unset | str = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        finished_on: Unset | str = UNSET
        if not isinstance(self.finished_on, Unset):
            finished_on = self.finished_on.isoformat()

        processed_on: Unset | str = UNSET
        if not isinstance(self.processed_on, Unset):
            processed_on = self.processed_on.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if state is not UNSET:
            field_dict["state"] = state
        if type_ is not UNSET:
            field_dict["type"] = type_
        if data is not UNSET:
            field_dict["data"] = data
        if error is not UNSET:
            field_dict["error"] = error
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if finished_on is not UNSET:
            field_dict["finishedOn"] = finished_on
        if processed_on is not UNSET:
            field_dict["processedOn"] = processed_on

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.job_data import JobData
        from peertube.models.job_error import JobError

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        _state = d.pop("state", UNSET)
        state: Unset | JobState
        if isinstance(_state, Unset):
            state = UNSET
        else:
            state = JobState(_state)

        _type_ = d.pop("type", UNSET)
        type_: Unset | JobType
        if isinstance(_type_, Unset):
            type_ = UNSET
        else:
            type_ = JobType(_type_)

        _data = d.pop("data", UNSET)
        data: Unset | JobData
        if isinstance(_data, Unset):
            data = UNSET
        else:
            data = JobData.from_dict(_data)

        _error = d.pop("error", UNSET)
        error: Unset | JobError
        if isinstance(_error, Unset):
            error = UNSET
        else:
            error = JobError.from_dict(_error)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Unset | datetime.datetime
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _finished_on = d.pop("finishedOn", UNSET)
        finished_on: Unset | datetime.datetime
        if isinstance(_finished_on, Unset):
            finished_on = UNSET
        else:
            finished_on = isoparse(_finished_on)

        _processed_on = d.pop("processedOn", UNSET)
        processed_on: Unset | datetime.datetime
        if isinstance(_processed_on, Unset):
            processed_on = UNSET
        else:
            processed_on = isoparse(_processed_on)

        job = cls(
            id=id,
            state=state,
            type_=type_,
            data=data,
            error=error,
            created_at=created_at,
            finished_on=finished_on,
            processed_on=processed_on,
        )

        job.additional_properties = d
        return job

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.server_config_transcoding_hls import ServerConfigTranscodingHls
    from peertube.models.server_config_transcoding_web_videos import (
        ServerConfigTranscodingWebVideos,
    )


T = TypeVar("T", bound="ServerConfigTranscoding")


@_attrs_define
class ServerConfigTranscoding:
    """Attributes:
    hls (Union[Unset, ServerConfigTranscodingHls]):
    web_videos (Union[Unset, ServerConfigTranscodingWebVideos]):
    enabled_resolutions (Union[Unset, list[int]]):
    """

    hls: Union[Unset, "ServerConfigTranscodingHls"] = UNSET
    web_videos: Union[Unset, "ServerConfigTranscodingWebVideos"] = UNSET
    enabled_resolutions: Unset | list[int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        hls: Unset | dict[str, Any] = UNSET
        if not isinstance(self.hls, Unset):
            hls = self.hls.to_dict()

        web_videos: Unset | dict[str, Any] = UNSET
        if not isinstance(self.web_videos, Unset):
            web_videos = self.web_videos.to_dict()

        enabled_resolutions: Unset | list[int] = UNSET
        if not isinstance(self.enabled_resolutions, Unset):
            enabled_resolutions = self.enabled_resolutions

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if hls is not UNSET:
            field_dict["hls"] = hls
        if web_videos is not UNSET:
            field_dict["web_videos"] = web_videos
        if enabled_resolutions is not UNSET:
            field_dict["enabledResolutions"] = enabled_resolutions

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.server_config_transcoding_hls import (
            ServerConfigTranscodingHls,
        )
        from peertube.models.server_config_transcoding_web_videos import (
            ServerConfigTranscodingWebVideos,
        )

        d = dict(src_dict)
        _hls = d.pop("hls", UNSET)
        hls: Unset | ServerConfigTranscodingHls
        if isinstance(_hls, Unset):
            hls = UNSET
        else:
            hls = ServerConfigTranscodingHls.from_dict(_hls)

        _web_videos = d.pop("web_videos", UNSET)
        web_videos: Unset | ServerConfigTranscodingWebVideos
        if isinstance(_web_videos, Unset):
            web_videos = UNSET
        else:
            web_videos = ServerConfigTranscodingWebVideos.from_dict(_web_videos)

        enabled_resolutions = cast("list[int]", d.pop("enabledResolutions", UNSET))

        server_config_transcoding = cls(
            hls=hls, web_videos=web_videos, enabled_resolutions=enabled_resolutions
        )

        server_config_transcoding.additional_properties = d
        return server_config_transcoding

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Tests for peertube.api.shared_utils module"""

import httpx
import pytest

from peertube.api.shared_utils import build_response, parse_response
from peertube.errors import UnexpectedStatus


class TestSharedUtils:
    """Test cases for peertube API shared utilities"""

    def test_build_response_returns_response_object(self, client, httpx_mock):
        """Test build_response returns Response object"""
        httpx_mock.add_response(
            method="GET",
            url="https://test.example/api",
            json={"key": "value"},
            status_code=200,
        )

        with httpx.Client() as http_client:
            response = http_client.get("https://test.example/api")
            result = build_response(client=client, response=response)
            assert hasattr(result, "status_code")
            assert hasattr(result, "content")
            assert hasattr(result, "headers")
            assert hasattr(result, "parsed")

    def test_parse_response_returns_none_when_no_raise(self, client, mocker):
        """Test parse_response returns parsed JSON for successful responses"""
        mock_response = mocker.Mock(spec=httpx.Response)
        mock_response.status_code = 200
        mock_response.json.return_value = {"key": "value"}

        result = parse_response(client=client, response=mock_response)
        assert result == {"key": "value"}

    def test_parse_response_raises_when_configured(self, client, mocker):
        """Test parse_response raises UnexpectedStatus when configured"""
        mock_response = mocker.Mock(spec=httpx.Response)
        mock_response.status_code = 400
        mock_response.content = b"Bad Request"

        # Mock client to raise on unexpected status
        mocker.patch.object(client, "raise_on_unexpected_status", new=True)

        with pytest.raises(UnexpectedStatus):
            parse_response(client=client, response=mock_response)



from peertube.api.video_passwords.delete_api_v_1_videos_id_passwords_video_password_id import (  # noqa: E501
    sync,
)


class TestDeleteApiV1VideosIdPasswordsVideoPasswordId:
    def test_sync(self, auth_client, httpx_mock):
        # Mock the API response
        httpx_mock.add_response(
            method="DELETE",
            url="https://test.peertube.example/api/v1/videos/123/passwords/456",
            status_code=204,
        )

        # Call the sync function
        result = sync(id=123, video_password_id=456, client=auth_client)

        # Assert the result
        assert result is None



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.video_stats_overall_countries_item import (
        VideoStatsOverallCountriesItem,
    )
    from peertube.models.video_stats_overall_subdivisions_item import (
        VideoStatsOverallSubdivisionsItem,
    )


T = TypeVar("T", bound="VideoStatsOverall")


@_attrs_define
class VideoStatsOverall:
    """Attributes:
    average_watch_time (Union[Unset, float]):
    total_watch_time (Union[Unset, float]):
    viewers_peak (Union[Unset, float]):
    total_viewers (Union[Unset, float]):
    viewers_peak_date (Union[Unset, datetime.datetime]):
    countries (Union[Unset, list['VideoStatsOverallCountriesItem']]):
    subdivisions (Union[Unset, list['VideoStatsOverallSubdivisionsItem']]):
    """

    average_watch_time: Unset | float = UNSET
    total_watch_time: Unset | float = UNSET
    viewers_peak: Unset | float = UNSET
    total_viewers: Unset | float = UNSET
    viewers_peak_date: Unset | datetime.datetime = UNSET
    countries: Unset | list["VideoStatsOverallCountriesItem"] = UNSET
    subdivisions: Unset | list["VideoStatsOverallSubdivisionsItem"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        average_watch_time = self.average_watch_time

        total_watch_time = self.total_watch_time

        viewers_peak = self.viewers_peak

        total_viewers = self.total_viewers

        viewers_peak_date: Unset | str = UNSET
        if not isinstance(self.viewers_peak_date, Unset):
            viewers_peak_date = self.viewers_peak_date.isoformat()

        countries: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.countries, Unset):
            countries = []
            for countries_item_data in self.countries:
                countries_item = countries_item_data.to_dict()
                countries.append(countries_item)

        subdivisions: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.subdivisions, Unset):
            subdivisions = []
            for subdivisions_item_data in self.subdivisions:
                subdivisions_item = subdivisions_item_data.to_dict()
                subdivisions.append(subdivisions_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if average_watch_time is not UNSET:
            field_dict["averageWatchTime"] = average_watch_time
        if total_watch_time is not UNSET:
            field_dict["totalWatchTime"] = total_watch_time
        if viewers_peak is not UNSET:
            field_dict["viewersPeak"] = viewers_peak
        if total_viewers is not UNSET:
            field_dict["totalViewers"] = total_viewers
        if viewers_peak_date is not UNSET:
            field_dict["viewersPeakDate"] = viewers_peak_date
        if countries is not UNSET:
            field_dict["countries"] = countries
        if subdivisions is not UNSET:
            field_dict["subdivisions"] = subdivisions

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.video_stats_overall_countries_item import (
            VideoStatsOverallCountriesItem,
        )
        from peertube.models.video_stats_overall_subdivisions_item import (
            VideoStatsOverallSubdivisionsItem,
        )

        d = dict(src_dict)
        average_watch_time = d.pop("averageWatchTime", UNSET)

        total_watch_time = d.pop("totalWatchTime", UNSET)

        viewers_peak = d.pop("viewersPeak", UNSET)

        total_viewers = d.pop("totalViewers", UNSET)

        _viewers_peak_date = d.pop("viewersPeakDate", UNSET)
        viewers_peak_date: Unset | datetime.datetime
        if isinstance(_viewers_peak_date, Unset):
            viewers_peak_date = UNSET
        else:
            viewers_peak_date = isoparse(_viewers_peak_date)

        countries = []
        _countries = d.pop("countries", UNSET)
        for countries_item_data in _countries or []:
            countries_item = VideoStatsOverallCountriesItem.from_dict(
                countries_item_data
            )

            countries.append(countries_item)

        subdivisions = []
        _subdivisions = d.pop("subdivisions", UNSET)
        for subdivisions_item_data in _subdivisions or []:
            subdivisions_item = VideoStatsOverallSubdivisionsItem.from_dict(
                subdivisions_item_data
            )

            subdivisions.append(subdivisions_item)

        video_stats_overall = cls(
            average_watch_time=average_watch_time,
            total_watch_time=total_watch_time,
            viewers_peak=viewers_peak,
            total_viewers=total_viewers,
            viewers_peak_date=viewers_peak_date,
            countries=countries,
            subdivisions=subdivisions,
        )

        video_stats_overall.additional_properties = d
        return video_stats_overall

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.models.o_auth_token_refresh_token_grant_type import (
    OAuthTokenRefreshTokenGrantType,
)
from peertube.types import UNSET, Unset

T = TypeVar("T", bound="OAuthTokenRefreshToken")


@_attrs_define
class OAuthTokenRefreshToken:
    """Attributes:
    grant_type (OAuthTokenRefreshTokenGrantType):  Default: OAuthTokenRefreshTokenGrantType.PASSWORD.
    refresh_token (str):  Example: 2e0d675df9fc96d2e4ec8a3ebbbf45eca9137bb7.
    client_id (Union[Unset, str]):  Example: v1ikx5hnfop4mdpnci8nsqh93c45rldf.
    client_secret (Union[Unset, str]):  Example: AjWiOapPltI6EnsWQwlFarRtLh4u8tDt.
    """

    refresh_token: str
    grant_type: OAuthTokenRefreshTokenGrantType = (
        OAuthTokenRefreshTokenGrantType.PASSWORD
    )
    client_id: Unset | str = UNSET
    client_secret: Unset | str = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert to dictionary."""

        grant_type = self.grant_type.value

        refresh_token = self.refresh_token

        client_id = self.client_id

        client_secret = self.client_secret

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "grant_type": grant_type,
                "refresh_token": refresh_token,
            }
        )
        if client_id is not UNSET:
            field_dict["client_id"] = client_id
        if client_secret is not UNSET:
            field_dict["client_secret"] = client_secret

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create from dictionary."""

        d = dict(src_dict)
        grant_type = OAuthTokenRefreshTokenGrantType(d.pop("grant_type"))

        refresh_token = d.pop("refresh_token")

        client_id = d.pop("client_id", UNSET)

        client_secret = d.pop("client_secret", UNSET)

        o_auth_token_refresh_token = cls(
            grant_type=grant_type,
            refresh_token=refresh_token,
            client_id=client_id,
            client_secret=client_secret,
        )

        o_auth_token_refresh_token.additional_properties = d
        return o_auth_token_refresh_token

    @property
    def additional_keys(self) -> list[str]:
        """Get additional keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Tests for get_mirrored_videos function."""

from peertube.api.video_mirroring.get_mirrored_videos import sync
from peertube.models.get_mirrored_videos_target import GetMirroredVideosTarget


def test_get_mirrored_videos_success(
    httpx_mock, auth_client, sample_mirrored_video_data
):
    """Test successful retrieval of mirrored videos."""
    # Mock HTTP response
    httpx_mock.add_response(
        method="GET",
        url="https://test.peertube.example/api/v1/server/redundancy/videos?target=my-videos&count=15",
        status_code=200,
        json=sample_mirrored_video_data,
    )

    # Test the function
    result = sync(client=auth_client, target=GetMirroredVideosTarget.MY_VIDEOS)

    assert result is not None
    assert len(result) == 2
    assert result[0].id == 1
    assert result[0].name == "Test Video 1"
    assert result[1].id == 2
    assert result[1].name == "Test Video 2"



from http import HTTPStatus
from typing import Any, cast
from uuid import UUID

import httpx
from pydantic import ConfigDict, validate_call

from peertube import errors
from peertube.client import AuthenticatedClient, Client
from peertube.models.video_password_list import VideoPasswordList
from peertube.types import UNSET, Response, Unset


def _get_kwargs(
    id: UUID | int | str,
    *,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["start"] = start

    params["count"] = count

    params["sort"] = sort
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/api/v1/videos/{id}/passwords",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | VideoPasswordList | None:
    if response.status_code == 204:
        response_204 = VideoPasswordList.from_dict(response.json())

        return response_204
    if response.status_code == 400:
        response_400 = cast("Any", None)
        return response_400
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any | VideoPasswordList]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
def sync_detailed(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Response[Any | VideoPasswordList]:
    """List video passwords

     **PeerTube >=6.0**
    Args:
        id (Union[UUID, int, str]): Unique identifier for the entity.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, VideoPasswordList]]
    """

    kwargs = _get_kwargs(id=id, start=start, count=count, sort=sort)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
def sync(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Any | VideoPasswordList | None:
    """List video passwords

     **PeerTube >=6.0**
    Args:
        id (Union[UUID, int, str]): Unique identifier for the entity.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, VideoPasswordList]
    """

    return sync_detailed(
        id=id, client=client, start=start, count=count, sort=sort
    ).parsed


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
async def asyncio_detailed(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Response[Any | VideoPasswordList]:
    """List video passwords

     **PeerTube >=6.0**
    Args:
        id (Union[UUID, int, str]): Unique identifier for the entity.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, VideoPasswordList]]
    """

    kwargs = _get_kwargs(id=id, start=start, count=count, sort=sort)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
async def asyncio(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    sort: Unset | str = UNSET,
) -> Any | VideoPasswordList | None:
    """List video passwords

     **PeerTube >=6.0**
    Args:
        id (Union[UUID, int, str]): Unique identifier for the entity.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        sort (Union[Unset, str]):  Example: -createdAt.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, VideoPasswordList]
    """

    return (
        await asyncio_detailed(
            id=id, client=client, start=start, count=count, sort=sort
        )
    ).parsed



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.user_registration_state import UserRegistrationState
    from peertube.models.user_registration_user_type_0 import UserRegistrationUserType0


T = TypeVar("T", bound="UserRegistration")


@_attrs_define
class UserRegistration:
    """Attributes:
    id (Union[Unset, int]):  Example: 42.
    state (Union[Unset, UserRegistrationState]):
    registration_reason (Union[Unset, str]):
    moderation_response (Union[None, Unset, str]):
    username (Union[Unset, str]):
    email (Union[Unset, str]):
    email_verified (Union[Unset, bool]):
    account_display_name (Union[Unset, str]):
    channel_handle (Union[Unset, str]):
    channel_display_name (Union[Unset, str]):
    created_at (Union[Unset, datetime.datetime]):
    updated_at (Union[Unset, datetime.datetime]):
    user (Union['UserRegistrationUserType0', None, Unset]): If the registration has been accepted, this is a partial
        user object created by the registration
    """

    id: Unset | int = UNSET
    state: Union[Unset, "UserRegistrationState"] = UNSET
    registration_reason: Unset | str = UNSET
    moderation_response: None | Unset | str = UNSET
    username: Unset | str = UNSET
    email: Unset | str = UNSET
    email_verified: Unset | bool = UNSET
    account_display_name: Unset | str = UNSET
    channel_handle: Unset | str = UNSET
    channel_display_name: Unset | str = UNSET
    created_at: Unset | datetime.datetime = UNSET
    updated_at: Unset | datetime.datetime = UNSET
    user: Union["UserRegistrationUserType0", None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        from peertube.models.user_registration_user_type_0 import (
            UserRegistrationUserType0,
        )

        id = self.id

        state: Unset | dict[str, Any] = UNSET
        if not isinstance(self.state, Unset):
            state = self.state.to_dict()

        registration_reason = self.registration_reason

        moderation_response: None | Unset | str
        if isinstance(self.moderation_response, Unset):
            moderation_response = UNSET
        else:
            moderation_response = self.moderation_response

        username = self.username

        email = self.email

        email_verified = self.email_verified

        account_display_name = self.account_display_name

        channel_handle = self.channel_handle

        channel_display_name = self.channel_display_name

        created_at: Unset | str = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Unset | str = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        user: None | Unset | dict[str, Any]
        if isinstance(self.user, Unset):
            user = UNSET
        elif isinstance(self.user, UserRegistrationUserType0):
            user = self.user.to_dict()
        else:
            user = self.user

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if state is not UNSET:
            field_dict["state"] = state
        if registration_reason is not UNSET:
            field_dict["registrationReason"] = registration_reason
        if moderation_response is not UNSET:
            field_dict["moderationResponse"] = moderation_response
        if username is not UNSET:
            field_dict["username"] = username
        if email is not UNSET:
            field_dict["email"] = email
        if email_verified is not UNSET:
            field_dict["emailVerified"] = email_verified
        if account_display_name is not UNSET:
            field_dict["accountDisplayName"] = account_display_name
        if channel_handle is not UNSET:
            field_dict["channelHandle"] = channel_handle
        if channel_display_name is not UNSET:
            field_dict["channelDisplayName"] = channel_display_name
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at
        if user is not UNSET:
            field_dict["user"] = user

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.user_registration_state import UserRegistrationState
        from peertube.models.user_registration_user_type_0 import (
            UserRegistrationUserType0,
        )

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        _state = d.pop("state", UNSET)
        state: Unset | UserRegistrationState
        if isinstance(_state, Unset):
            state = UNSET
        else:
            state = UserRegistrationState.from_dict(_state)

        registration_reason = d.pop("registrationReason", UNSET)

        def _parse_moderation_response(data: object) -> None | Unset | str:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast("None | Unset | str", data)

        moderation_response = _parse_moderation_response(
            d.pop("moderationResponse", UNSET)
        )

        username = d.pop("username", UNSET)

        email = d.pop("email", UNSET)

        email_verified = d.pop("emailVerified", UNSET)

        account_display_name = d.pop("accountDisplayName", UNSET)

        channel_handle = d.pop("channelHandle", UNSET)

        channel_display_name = d.pop("channelDisplayName", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Unset | datetime.datetime
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Unset | datetime.datetime
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        def _parse_user(
            data: object,
        ) -> Union["UserRegistrationUserType0", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError
                user_type_0 = UserRegistrationUserType0.from_dict(data)

                return user_type_0
            except:  # noqa: E722
                pass
            return cast("UserRegistrationUserType0 | None | Unset", data)

        user = _parse_user(d.pop("user", UNSET))

        user_registration = cls(
            id=id,
            state=state,
            registration_reason=registration_reason,
            moderation_response=moderation_response,
            username=username,
            email=email,
            email_verified=email_verified,
            account_display_name=account_display_name,
            channel_handle=channel_handle,
            channel_display_name=channel_display_name,
            created_at=created_at,
            updated_at=updated_at,
            user=user,
        )

        user_registration.additional_properties = d
        return user_registration

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, cast

import httpx

from peertube import errors
from peertube.client import AuthenticatedClient, Client
from peertube.models.search_playlists_response_200 import SearchPlaylistsResponse200
from peertube.models.search_playlists_search_target import SearchPlaylistsSearchTarget
from peertube.types import UNSET, Response, Unset


def _get_kwargs(
    *,
    search: str,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    search_target: Unset | SearchPlaylistsSearchTarget = UNSET,
    sort: Unset | str = UNSET,
    host: Unset | str = UNSET,
    uuids: Unset | Any = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["search"] = search

    params["start"] = start

    params["count"] = count
    json_search_target: Unset | str = UNSET
    if not isinstance(search_target, Unset):
        json_search_target = search_target.value

    params["searchTarget"] = json_search_target

    params["sort"] = sort

    params["host"] = host

    params["uuids"] = uuids
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/api/v1/search/video-playlists",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | SearchPlaylistsResponse200 | None:
    if response.status_code == 200:
        response_200 = SearchPlaylistsResponse200.from_dict(response.json())

        return response_200
    if response.status_code == 500:
        response_500 = cast("Any", None)
        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any | SearchPlaylistsResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient | Client,
    search: str,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    search_target: Unset | SearchPlaylistsSearchTarget = UNSET,
    sort: Unset | str = UNSET,
    host: Unset | str = UNSET,
    uuids: Unset | Any = UNSET,
) -> Response[Any | SearchPlaylistsResponse200]:
    """Search playlists


    Args:
        search (str): Search query filter.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        search_target (Union[Unset, SearchPlaylistsSearchTarget]): Search filter for target.
        sort (Union[Unset, str]):  Example: -createdAt.
        host (Union[Unset, str]): Parameter for host.
        uuids (Union[Unset, Any]): Parameter for uuids.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, SearchPlaylistsResponse200]]
    """

    kwargs = _get_kwargs(
        search=search,
        start=start,
        count=count,
        search_target=search_target,
        sort=sort,
        host=host,
        uuids=uuids,
    )

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient | Client,
    search: str,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    search_target: Unset | SearchPlaylistsSearchTarget = UNSET,
    sort: Unset | str = UNSET,
    host: Unset | str = UNSET,
    uuids: Unset | Any = UNSET,
) -> Any | SearchPlaylistsResponse200 | None:
    """Search playlists


    Args:
        search (str): Search query filter.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        search_target (Union[Unset, SearchPlaylistsSearchTarget]): Search filter for target.
        sort (Union[Unset, str]):  Example: -createdAt.
        host (Union[Unset, str]): Parameter for host.
        uuids (Union[Unset, Any]): Parameter for uuids.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, SearchPlaylistsResponse200]
    """

    return sync_detailed(
        client=client,
        search=search,
        start=start,
        count=count,
        search_target=search_target,
        sort=sort,
        host=host,
        uuids=uuids,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient | Client,
    search: str,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    search_target: Unset | SearchPlaylistsSearchTarget = UNSET,
    sort: Unset | str = UNSET,
    host: Unset | str = UNSET,
    uuids: Unset | Any = UNSET,
) -> Response[Any | SearchPlaylistsResponse200]:
    """Search playlists


    Args:
        search (str): Search query filter.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        search_target (Union[Unset, SearchPlaylistsSearchTarget]): Search filter for target.
        sort (Union[Unset, str]):  Example: -createdAt.
        host (Union[Unset, str]): Parameter for host.
        uuids (Union[Unset, Any]): Parameter for uuids.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, SearchPlaylistsResponse200]]
    """

    kwargs = _get_kwargs(
        search=search,
        start=start,
        count=count,
        search_target=search_target,
        sort=sort,
        host=host,
        uuids=uuids,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient | Client,
    search: str,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    search_target: Unset | SearchPlaylistsSearchTarget = UNSET,
    sort: Unset | str = UNSET,
    host: Unset | str = UNSET,
    uuids: Unset | Any = UNSET,
) -> Any | SearchPlaylistsResponse200 | None:
    """Search playlists


    Args:
        search (str): Search query filter.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        search_target (Union[Unset, SearchPlaylistsSearchTarget]): Search filter for target.
        sort (Union[Unset, str]):  Example: -createdAt.
        host (Union[Unset, str]): Parameter for host.
        uuids (Union[Unset, Any]): Parameter for uuids.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, SearchPlaylistsResponse200]
    """

    return (
        await asyncio_detailed(
            client=client,
            search=search,
            start=start,
            count=count,
            search_target=search_target,
            sort=sort,
            host=host,
            uuids=uuids,
        )
    ).parsed



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.video import Video


T = TypeVar("T", bound="PlaylistElement")


@_attrs_define
class PlaylistElement:
    """Attributes:
    position (Union[Unset, int]):
    start_timestamp (Union[Unset, int]):
    stop_timestamp (Union[Unset, int]):
    video (Union['Video', None, Unset]):
    """

    position: Unset | int = UNSET
    start_timestamp: Unset | int = UNSET
    stop_timestamp: Unset | int = UNSET
    video: Union["Video", None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        from peertube.models.video import Video

        position = self.position

        start_timestamp = self.start_timestamp

        stop_timestamp = self.stop_timestamp

        video: None | Unset | dict[str, Any]
        if isinstance(self.video, Unset):
            video = UNSET
        elif isinstance(self.video, Video):
            video = self.video.to_dict()
        else:
            video = self.video

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if position is not UNSET:
            field_dict["position"] = position
        if start_timestamp is not UNSET:
            field_dict["startTimestamp"] = start_timestamp
        if stop_timestamp is not UNSET:
            field_dict["stopTimestamp"] = stop_timestamp
        if video is not UNSET:
            field_dict["video"] = video

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.video import Video

        d = dict(src_dict)
        position = d.pop("position", UNSET)

        start_timestamp = d.pop("startTimestamp", UNSET)

        stop_timestamp = d.pop("stopTimestamp", UNSET)

        def _parse_video(data: object) -> Union["Video", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError
                video_type_1 = Video.from_dict(data)

                return video_type_1
            except:  # noqa: E722
                pass
            return cast("Video | None | Unset", data)

        video = _parse_video(d.pop("video", UNSET))

        playlist_element = cls(
            position=position,
            start_timestamp=start_timestamp,
            stop_timestamp=stop_timestamp,
            video=video,
        )

        playlist_element.additional_properties = d
        return playlist_element

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

T = TypeVar("T", bound="LiveVideoSessionResponseReplayVideo")


@_attrs_define
class LiveVideoSessionResponseReplayVideo:
    """Video replay information

    Attributes:
        id (Union[Unset, float]):
        uuid (Union[Unset, UUID]):  Example: 9c9de5e8-0a1e-484a-b099-e80766180a6d.
        short_uuid (Union[Unset, str]): translation of a uuid v4 with a bigger alphabet to have a shorter uuid Example:
            2y84q2MQUMWPbiEcxNXMgC.
    """

    id: Unset | float = UNSET
    uuid: Unset | UUID = UNSET
    short_uuid: Unset | str = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        id = self.id

        uuid: Unset | str = UNSET
        if not isinstance(self.uuid, Unset):
            uuid = str(self.uuid)

        short_uuid = self.short_uuid

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if uuid is not UNSET:
            field_dict["uuid"] = uuid
        if short_uuid is not UNSET:
            field_dict["shortUUID"] = short_uuid

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        _uuid = d.pop("uuid", UNSET)
        uuid: Unset | UUID
        if isinstance(_uuid, Unset):
            uuid = UNSET
        else:
            uuid = UUID(_uuid)

        short_uuid = d.pop("shortUUID", UNSET)

        live_video_session_response_replay_video = cls(
            id=id, uuid=uuid, short_uuid=short_uuid
        )

        live_video_session_response_replay_video.additional_properties = d
        return live_video_session_response_replay_video

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

T = TypeVar("T", bound="ServerConfigCustomUser")


@_attrs_define
class ServerConfigCustomUser:
    """Settings that apply to new users, if registration is enabled

    Attributes:
        video_quota (Union[Unset, int]):  Example: 16810141515.
        video_quota_daily (Union[Unset, int]):  Example: 1681014151.
    """

    video_quota: Unset | int = UNSET
    video_quota_daily: Unset | int = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        video_quota = self.video_quota

        video_quota_daily = self.video_quota_daily

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if video_quota is not UNSET:
            field_dict["videoQuota"] = video_quota
        if video_quota_daily is not UNSET:
            field_dict["videoQuotaDaily"] = video_quota_daily

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        video_quota = d.pop("videoQuota", UNSET)

        video_quota_daily = d.pop("videoQuotaDaily", UNSET)

        server_config_custom_user = cls(
            video_quota=video_quota, video_quota_daily=video_quota_daily
        )

        server_config_custom_user.additional_properties = d
        return server_config_custom_user

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.models.user_viewing_video_view_event import UserViewingVideoViewEvent
from peertube.models.video_stats_user_agent_device import VideoStatsUserAgentDevice
from peertube.types import UNSET, Unset

T = TypeVar("T", bound="UserViewingVideo")


@_attrs_define
class UserViewingVideo:
    """Attributes:
    current_time (int): timestamp within the video, in seconds Example: 5.
    view_event (Union[Unset, UserViewingVideoViewEvent]): Event since last viewing call:
         * `seek` - If the user seeked the video
    session_id (Union[Unset, str]): Optional param to represent the current viewer session. Used by the backend to
        properly count one view per session per video. PeerTube admin can configure the server to not trust this
        `sessionId` parameter but use the request IP address instead to identify a viewer.
    client (Union[Unset, str]): Client software used to watch the video. For example "Firefox", "PeerTube Approval
        Android", etc.
    device (Union[Unset, VideoStatsUserAgentDevice]):
    operating_system (Union[Unset, str]): Operating system used to watch the video. For example "Windows", "Ubuntu", etc.
    """

    current_time: int
    view_event: Unset | UserViewingVideoViewEvent = UNSET
    session_id: Unset | str = UNSET
    client: Unset | str = UNSET
    device: Unset | VideoStatsUserAgentDevice = UNSET
    operating_system: Unset | str = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        current_time = self.current_time

        view_event: Unset | str = UNSET
        if not isinstance(self.view_event, Unset):
            view_event = self.view_event.value

        session_id = self.session_id

        client = self.client

        device: Unset | str = UNSET
        if not isinstance(self.device, Unset):
            device = self.device.value

        operating_system = self.operating_system

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "currentTime": current_time,
            }
        )
        if view_event is not UNSET:
            field_dict["viewEvent"] = view_event
        if session_id is not UNSET:
            field_dict["sessionId"] = session_id
        if client is not UNSET:
            field_dict["client"] = client
        if device is not UNSET:
            field_dict["device"] = device
        if operating_system is not UNSET:
            field_dict["operatingSystem"] = operating_system

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        current_time = d.pop("currentTime")

        _view_event = d.pop("viewEvent", UNSET)
        view_event: Unset | UserViewingVideoViewEvent
        if isinstance(_view_event, Unset):
            view_event = UNSET
        else:
            view_event = UserViewingVideoViewEvent(_view_event)

        session_id = d.pop("sessionId", UNSET)

        client = d.pop("client", UNSET)

        _device = d.pop("device", UNSET)
        device: Unset | VideoStatsUserAgentDevice
        if isinstance(_device, Unset):
            device = UNSET
        else:
            device = VideoStatsUserAgentDevice(_device)

        operating_system = d.pop("operatingSystem", UNSET)

        user_viewing_video = cls(
            current_time=current_time,
            view_event=view_event,
            session_id=session_id,
            client=client,
            device=device,
            operating_system=operating_system,
        )

        user_viewing_video.additional_properties = d
        return user_viewing_video

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Shared utilities for API client functions."""

from http import HTTPStatus
from typing import Any

import httpx

from peertube import errors
from peertube.client import AuthenticatedClient, Client
from peertube.types import Response


def build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any]:
    """Build a Response object from httpx response."""
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=parse_response(client=client, response=response),
    )


def parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | None:
    """Parse response, raising error if configured."""
    if response.status_code >= 400:
        if client.raise_on_unexpected_status:
            raise errors.UnexpectedStatus(response.status_code, response.content)
        else:
            return None
    else:
        # For successful responses, try to parse JSON
        try:
            return response.json()
        except ValueError:
            return None



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.server_config_custom_instance_customizations import (
        ServerConfigCustomInstanceCustomizations,
    )
    from peertube.models.server_config_custom_instance_social import (
        ServerConfigCustomInstanceSocial,
    )
    from peertube.models.server_config_custom_instance_support import (
        ServerConfigCustomInstanceSupport,
    )


T = TypeVar("T", bound="ServerConfigCustomInstance")


@_attrs_define
class ServerConfigCustomInstance:
    """Attributes:
    name (Union[Unset, str]):
    short_description (Union[Unset, str]):
    description (Union[Unset, str]):
    terms (Union[Unset, str]):
    code_of_conduct (Union[Unset, str]):
    creation_reason (Union[Unset, str]):
    moderation_information (Union[Unset, str]):
    administrator (Union[Unset, str]):
    maintenance_lifetime (Union[Unset, str]):
    business_model (Union[Unset, str]):
    hardware_information (Union[Unset, str]):
    languages (Union[Unset, list[str]]):
    categories (Union[Unset, list[float]]):
    is_nsfw (Union[Unset, bool]):
    default_nsfw_policy (Union[Unset, str]):
    server_country (Union[Unset, str]):
    support (Union[Unset, ServerConfigCustomInstanceSupport]):
    social (Union[Unset, ServerConfigCustomInstanceSocial]):
    default_client_route (Union[Unset, str]):
    customizations (Union[Unset, ServerConfigCustomInstanceCustomizations]):
    """

    name: Unset | str = UNSET
    short_description: Unset | str = UNSET
    description: Unset | str = UNSET
    terms: Unset | str = UNSET
    code_of_conduct: Unset | str = UNSET
    creation_reason: Unset | str = UNSET
    moderation_information: Unset | str = UNSET
    administrator: Unset | str = UNSET
    maintenance_lifetime: Unset | str = UNSET
    business_model: Unset | str = UNSET
    hardware_information: Unset | str = UNSET
    languages: Unset | list[str] = UNSET
    categories: Unset | list[float] = UNSET
    is_nsfw: Unset | bool = UNSET
    default_nsfw_policy: Unset | str = UNSET
    server_country: Unset | str = UNSET
    support: Union[Unset, "ServerConfigCustomInstanceSupport"] = UNSET
    social: Union[Unset, "ServerConfigCustomInstanceSocial"] = UNSET
    default_client_route: Unset | str = UNSET
    customizations: Union[Unset, "ServerConfigCustomInstanceCustomizations"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        name = self.name

        short_description = self.short_description

        description = self.description

        terms = self.terms

        code_of_conduct = self.code_of_conduct

        creation_reason = self.creation_reason

        moderation_information = self.moderation_information

        administrator = self.administrator

        maintenance_lifetime = self.maintenance_lifetime

        business_model = self.business_model

        hardware_information = self.hardware_information

        languages: Unset | list[str] = UNSET
        if not isinstance(self.languages, Unset):
            languages = self.languages

        categories: Unset | list[float] = UNSET
        if not isinstance(self.categories, Unset):
            categories = self.categories

        is_nsfw = self.is_nsfw

        default_nsfw_policy = self.default_nsfw_policy

        server_country = self.server_country

        support: Unset | dict[str, Any] = UNSET
        if not isinstance(self.support, Unset):
            support = self.support.to_dict()

        social: Unset | dict[str, Any] = UNSET
        if not isinstance(self.social, Unset):
            social = self.social.to_dict()

        default_client_route = self.default_client_route

        customizations: Unset | dict[str, Any] = UNSET
        if not isinstance(self.customizations, Unset):
            customizations = self.customizations.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if short_description is not UNSET:
            field_dict["shortDescription"] = short_description
        if description is not UNSET:
            field_dict["description"] = description
        if terms is not UNSET:
            field_dict["terms"] = terms
        if code_of_conduct is not UNSET:
            field_dict["codeOfConduct"] = code_of_conduct
        if creation_reason is not UNSET:
            field_dict["creationReason"] = creation_reason
        if moderation_information is not UNSET:
            field_dict["moderationInformation"] = moderation_information
        if administrator is not UNSET:
            field_dict["administrator"] = administrator
        if maintenance_lifetime is not UNSET:
            field_dict["maintenanceLifetime"] = maintenance_lifetime
        if business_model is not UNSET:
            field_dict["businessModel"] = business_model
        if hardware_information is not UNSET:
            field_dict["hardwareInformation"] = hardware_information
        if languages is not UNSET:
            field_dict["languages"] = languages
        if categories is not UNSET:
            field_dict["categories"] = categories
        if is_nsfw is not UNSET:
            field_dict["isNSFW"] = is_nsfw
        if default_nsfw_policy is not UNSET:
            field_dict["defaultNSFWPolicy"] = default_nsfw_policy
        if server_country is not UNSET:
            field_dict["serverCountry"] = server_country
        if support is not UNSET:
            field_dict["support"] = support
        if social is not UNSET:
            field_dict["social"] = social
        if default_client_route is not UNSET:
            field_dict["defaultClientRoute"] = default_client_route
        if customizations is not UNSET:
            field_dict["customizations"] = customizations

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.server_config_custom_instance_customizations import (
            ServerConfigCustomInstanceCustomizations,
        )
        from peertube.models.server_config_custom_instance_social import (
            ServerConfigCustomInstanceSocial,
        )
        from peertube.models.server_config_custom_instance_support import (
            ServerConfigCustomInstanceSupport,
        )

        d = dict(src_dict)
        name = d.pop("name", UNSET)

        short_description = d.pop("shortDescription", UNSET)

        description = d.pop("description", UNSET)

        terms = d.pop("terms", UNSET)

        code_of_conduct = d.pop("codeOfConduct", UNSET)

        creation_reason = d.pop("creationReason", UNSET)

        moderation_information = d.pop("moderationInformation", UNSET)

        administrator = d.pop("administrator", UNSET)

        maintenance_lifetime = d.pop("maintenanceLifetime", UNSET)

        business_model = d.pop("businessModel", UNSET)

        hardware_information = d.pop("hardwareInformation", UNSET)

        languages = cast("list[str]", d.pop("languages", UNSET))

        categories = cast("list[float]", d.pop("categories", UNSET))

        is_nsfw = d.pop("isNSFW", UNSET)

        default_nsfw_policy = d.pop("defaultNSFWPolicy", UNSET)

        server_country = d.pop("serverCountry", UNSET)

        _support = d.pop("support", UNSET)
        support: Unset | ServerConfigCustomInstanceSupport
        if isinstance(_support, Unset):
            support = UNSET
        else:
            support = ServerConfigCustomInstanceSupport.from_dict(_support)

        _social = d.pop("social", UNSET)
        social: Unset | ServerConfigCustomInstanceSocial
        if isinstance(_social, Unset):
            social = UNSET
        else:
            social = ServerConfigCustomInstanceSocial.from_dict(_social)

        default_client_route = d.pop("defaultClientRoute", UNSET)

        _customizations = d.pop("customizations", UNSET)
        customizations: Unset | ServerConfigCustomInstanceCustomizations
        if isinstance(_customizations, Unset):
            customizations = UNSET
        else:
            customizations = ServerConfigCustomInstanceCustomizations.from_dict(
                _customizations
            )

        server_config_custom_instance = cls(
            name=name,
            short_description=short_description,
            description=description,
            terms=terms,
            code_of_conduct=code_of_conduct,
            creation_reason=creation_reason,
            moderation_information=moderation_information,
            administrator=administrator,
            maintenance_lifetime=maintenance_lifetime,
            business_model=business_model,
            hardware_information=hardware_information,
            languages=languages,
            categories=categories,
            is_nsfw=is_nsfw,
            default_nsfw_policy=default_nsfw_policy,
            server_country=server_country,
            support=support,
            social=social,
            default_client_route=default_client_route,
            customizations=customizations,
        )

        server_config_custom_instance.additional_properties = d
        return server_config_custom_instance

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Tests for get_syndicated_subscription_videos function."""

import json

from peertube.api.video_feeds.get_syndicated_subscription_videos import sync
from peertube.models.get_syndicated_subscription_videos_format import (
    GetSyndicatedSubscriptionVideosFormat,
)


def test_get_syndicated_subscription_videos_success(
    httpx_mock, client, sample_video_feed_data
):
    """Test successful retrieval of syndicated subscription videos."""
    # Mock HTTP response
    httpx_mock.add_response(
        method="GET",
        url="https://test.peertube.example/feeds/subscriptions.xml?accountId=test-account&token=test-token",
        status_code=200,
        text=json.dumps(sample_video_feed_data),
    )

    # Test the function
    result = sync(
        format_=GetSyndicatedSubscriptionVideosFormat.XML,
        client=client,
        account_id="test-account",
        token="test-token",  # noqa: S106
    )

    assert result is not None
    assert len(result) == 2
    assert result[0].mediatitle == "Test Video 1"
    assert result[0].guid == "123"
    assert result[1].link == "https://example.com/videos/watch/456"



from enum import Enum


class CreateVideoTranscodingBodyTranscodingType(str, Enum):
    """CreateVideoTranscodingBodyTranscodingType enumeration."""

    HLS = "hls"
    WEB_VIDEO = "web-video"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.server_config_custom_defaults_p2p_embed import (
        ServerConfigCustomDefaultsP2PEmbed,
    )
    from peertube.models.server_config_custom_defaults_p2p_webapp import (
        ServerConfigCustomDefaultsP2PWebapp,
    )


T = TypeVar("T", bound="ServerConfigCustomDefaultsP2P")


@_attrs_define
class ServerConfigCustomDefaultsP2P:
    """Attributes:
    webapp (Union[Unset, ServerConfigCustomDefaultsP2PWebapp]):
    embed (Union[Unset, ServerConfigCustomDefaultsP2PEmbed]):
    """

    webapp: Union[Unset, "ServerConfigCustomDefaultsP2PWebapp"] = UNSET
    embed: Union[Unset, "ServerConfigCustomDefaultsP2PEmbed"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        webapp: Unset | dict[str, Any] = UNSET
        if not isinstance(self.webapp, Unset):
            webapp = self.webapp.to_dict()

        embed: Unset | dict[str, Any] = UNSET
        if not isinstance(self.embed, Unset):
            embed = self.embed.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if webapp is not UNSET:
            field_dict["webapp"] = webapp
        if embed is not UNSET:
            field_dict["embed"] = embed

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.server_config_custom_defaults_p2p_embed import (
            ServerConfigCustomDefaultsP2PEmbed,
        )
        from peertube.models.server_config_custom_defaults_p2p_webapp import (
            ServerConfigCustomDefaultsP2PWebapp,
        )

        d = dict(src_dict)
        _webapp = d.pop("webapp", UNSET)
        webapp: Unset | ServerConfigCustomDefaultsP2PWebapp
        if isinstance(_webapp, Unset):
            webapp = UNSET
        else:
            webapp = ServerConfigCustomDefaultsP2PWebapp.from_dict(_webapp)

        _embed = d.pop("embed", UNSET)
        embed: Unset | ServerConfigCustomDefaultsP2PEmbed
        if isinstance(_embed, Unset):
            embed = UNSET
        else:
            embed = ServerConfigCustomDefaultsP2PEmbed.from_dict(_embed)

        server_config_custom_defaults_p2p = cls(webapp=webapp, embed=embed)

        server_config_custom_defaults_p2p.additional_properties = d
        return server_config_custom_defaults_p2p

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class FollowState(str, Enum):
    """FollowState enumeration."""

    ACCEPTED = "accepted"
    PENDING = "pending"

    def __str__(self) -> str:
        """Return string representation."""

        return str(self.value)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.server_config_search_remote_uri import (
        ServerConfigSearchRemoteUri,
    )


T = TypeVar("T", bound="ServerConfigSearch")


@_attrs_define
class ServerConfigSearch:
    """Attributes:
    remote_uri (Union[Unset, ServerConfigSearchRemoteUri]):
    """

    remote_uri: Union[Unset, "ServerConfigSearchRemoteUri"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        remote_uri: Unset | dict[str, Any] = UNSET
        if not isinstance(self.remote_uri, Unset):
            remote_uri = self.remote_uri.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if remote_uri is not UNSET:
            field_dict["remoteUri"] = remote_uri

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.server_config_search_remote_uri import (
            ServerConfigSearchRemoteUri,
        )

        d = dict(src_dict)
        _remote_uri = d.pop("remoteUri", UNSET)
        remote_uri: Unset | ServerConfigSearchRemoteUri
        if isinstance(_remote_uri, Unset):
            remote_uri = UNSET
        else:
            remote_uri = ServerConfigSearchRemoteUri.from_dict(_remote_uri)

        server_config_search = cls(remote_uri=remote_uri)

        server_config_search.additional_properties = d
        return server_config_search

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.types import UNSET, Unset

T = TypeVar("T", bound="VideoCommentsForXMLItem")


@_attrs_define
class VideoCommentsForXMLItem:
    """Attributes:
    link (Union[Unset, str]):
    guid (Union[Unset, str]):
    pub_date (Union[Unset, datetime.datetime]):
    contentencoded (Union[Unset, str]):
    dccreator (Union[Unset, str]):
    """

    link: Unset | str = UNSET
    guid: Unset | str = UNSET
    pub_date: Unset | datetime.datetime = UNSET
    contentencoded: Unset | str = UNSET
    dccreator: Unset | str = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        link = self.link

        guid = self.guid

        pub_date: Unset | str = UNSET
        if not isinstance(self.pub_date, Unset):
            pub_date = self.pub_date.isoformat()

        contentencoded = self.contentencoded

        dccreator = self.dccreator

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if link is not UNSET:
            field_dict["link"] = link
        if guid is not UNSET:
            field_dict["guid"] = guid
        if pub_date is not UNSET:
            field_dict["pubDate"] = pub_date
        if contentencoded is not UNSET:
            field_dict["content:encoded"] = contentencoded
        if dccreator is not UNSET:
            field_dict["dc:creator"] = dccreator

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        link = d.pop("link", UNSET)

        guid = d.pop("guid", UNSET)

        _pub_date = d.pop("pubDate", UNSET)
        pub_date: Unset | datetime.datetime
        if isinstance(_pub_date, Unset):
            pub_date = UNSET
        else:
            pub_date = isoparse(_pub_date)

        contentencoded = d.pop("content:encoded", UNSET)

        dccreator = d.pop("dc:creator", UNSET)

        video_comments_for_xml_item = cls(
            link=link,
            guid=guid,
            pub_date=pub_date,
            contentencoded=contentencoded,
            dccreator=dccreator,
        )

        video_comments_for_xml_item.additional_properties = d
        return video_comments_for_xml_item

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

T = TypeVar("T", bound="PutApiV1UsersMeNotificationSettingsBody")


@_attrs_define
class PutApiV1UsersMeNotificationSettingsBody:
    """Attributes:
    abuse_as_moderator (Union[Unset, int]): Notification type. One of the following values, or a sum of multiple
        values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    video_auto_blacklist_as_moderator (Union[Unset, int]): Notification type. One of the following values, or a sum
        of multiple values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    new_user_registration (Union[Unset, int]): Notification type. One of the following values, or a sum of multiple
        values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    new_video_from_subscription (Union[Unset, int]): Notification type. One of the following values, or a sum of
        multiple values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    blacklist_on_my_video (Union[Unset, int]): Notification type. One of the following values, or a sum of multiple
        values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    my_video_published (Union[Unset, int]): Notification type. One of the following values, or a sum of multiple
        values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    my_video_import_finished (Union[Unset, int]): Notification type. One of the following values, or a sum of
        multiple values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    comment_mention (Union[Unset, int]): Notification type. One of the following values, or a sum of multiple
        values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    new_comment_on_my_video (Union[Unset, int]): Notification type. One of the following values, or a sum of
        multiple values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    new_follow (Union[Unset, int]): Notification type. One of the following values, or a sum of multiple values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    new_instance_follower (Union[Unset, int]): Notification type. One of the following values, or a sum of multiple
        values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    auto_instance_following (Union[Unset, int]): Notification type. One of the following values, or a sum of
        multiple values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    abuse_state_change (Union[Unset, int]): Notification type. One of the following values, or a sum of multiple
        values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    abuse_new_message (Union[Unset, int]): Notification type. One of the following values, or a sum of multiple
        values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    new_peer_tube_version (Union[Unset, int]): Notification type. One of the following values, or a sum of multiple
        values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    new_plugin_version (Union[Unset, int]): Notification type. One of the following values, or a sum of multiple
        values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    my_video_studio_edition_finished (Union[Unset, int]): Notification type. One of the following values, or a sum
        of multiple values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    my_video_transcription_generated (Union[Unset, int]): Notification type. One of the following values, or a sum
        of multiple values:
        - `0` NONE
        - `1` WEB
        - `2` EMAIL
    """

    abuse_as_moderator: Unset | int = UNSET
    video_auto_blacklist_as_moderator: Unset | int = UNSET
    new_user_registration: Unset | int = UNSET
    new_video_from_subscription: Unset | int = UNSET
    blacklist_on_my_video: Unset | int = UNSET
    my_video_published: Unset | int = UNSET
    my_video_import_finished: Unset | int = UNSET
    comment_mention: Unset | int = UNSET
    new_comment_on_my_video: Unset | int = UNSET
    new_follow: Unset | int = UNSET
    new_instance_follower: Unset | int = UNSET
    auto_instance_following: Unset | int = UNSET
    abuse_state_change: Unset | int = UNSET
    abuse_new_message: Unset | int = UNSET
    new_peer_tube_version: Unset | int = UNSET
    new_plugin_version: Unset | int = UNSET
    my_video_studio_edition_finished: Unset | int = UNSET
    my_video_transcription_generated: Unset | int = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        abuse_as_moderator = self.abuse_as_moderator

        video_auto_blacklist_as_moderator = self.video_auto_blacklist_as_moderator

        new_user_registration = self.new_user_registration

        new_video_from_subscription = self.new_video_from_subscription

        blacklist_on_my_video = self.blacklist_on_my_video

        my_video_published = self.my_video_published

        my_video_import_finished = self.my_video_import_finished

        comment_mention = self.comment_mention

        new_comment_on_my_video = self.new_comment_on_my_video

        new_follow = self.new_follow

        new_instance_follower = self.new_instance_follower

        auto_instance_following = self.auto_instance_following

        abuse_state_change = self.abuse_state_change

        abuse_new_message = self.abuse_new_message

        new_peer_tube_version = self.new_peer_tube_version

        new_plugin_version = self.new_plugin_version

        my_video_studio_edition_finished = self.my_video_studio_edition_finished

        my_video_transcription_generated = self.my_video_transcription_generated

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if abuse_as_moderator is not UNSET:
            field_dict["abuseAsModerator"] = abuse_as_moderator
        if video_auto_blacklist_as_moderator is not UNSET:
            field_dict["videoAutoBlacklistAsModerator"] = (
                video_auto_blacklist_as_moderator
            )
        if new_user_registration is not UNSET:
            field_dict["newUserRegistration"] = new_user_registration
        if new_video_from_subscription is not UNSET:
            field_dict["newVideoFromSubscription"] = new_video_from_subscription
        if blacklist_on_my_video is not UNSET:
            field_dict["blacklistOnMyVideo"] = blacklist_on_my_video
        if my_video_published is not UNSET:
            field_dict["myVideoPublished"] = my_video_published
        if my_video_import_finished is not UNSET:
            field_dict["myVideoImportFinished"] = my_video_import_finished
        if comment_mention is not UNSET:
            field_dict["commentMention"] = comment_mention
        if new_comment_on_my_video is not UNSET:
            field_dict["newCommentOnMyVideo"] = new_comment_on_my_video
        if new_follow is not UNSET:
            field_dict["newFollow"] = new_follow
        if new_instance_follower is not UNSET:
            field_dict["newInstanceFollower"] = new_instance_follower
        if auto_instance_following is not UNSET:
            field_dict["autoInstanceFollowing"] = auto_instance_following
        if abuse_state_change is not UNSET:
            field_dict["abuseStateChange"] = abuse_state_change
        if abuse_new_message is not UNSET:
            field_dict["abuseNewMessage"] = abuse_new_message
        if new_peer_tube_version is not UNSET:
            field_dict["newPeerTubeVersion"] = new_peer_tube_version
        if new_plugin_version is not UNSET:
            field_dict["newPluginVersion"] = new_plugin_version
        if my_video_studio_edition_finished is not UNSET:
            field_dict["myVideoStudioEditionFinished"] = (
                my_video_studio_edition_finished
            )
        if my_video_transcription_generated is not UNSET:
            field_dict["myVideoTranscriptionGenerated"] = (
                my_video_transcription_generated
            )

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        abuse_as_moderator = d.pop("abuseAsModerator", UNSET)

        video_auto_blacklist_as_moderator = d.pop(
            "videoAutoBlacklistAsModerator", UNSET
        )

        new_user_registration = d.pop("newUserRegistration", UNSET)

        new_video_from_subscription = d.pop("newVideoFromSubscription", UNSET)

        blacklist_on_my_video = d.pop("blacklistOnMyVideo", UNSET)

        my_video_published = d.pop("myVideoPublished", UNSET)

        my_video_import_finished = d.pop("myVideoImportFinished", UNSET)

        comment_mention = d.pop("commentMention", UNSET)

        new_comment_on_my_video = d.pop("newCommentOnMyVideo", UNSET)

        new_follow = d.pop("newFollow", UNSET)

        new_instance_follower = d.pop("newInstanceFollower", UNSET)

        auto_instance_following = d.pop("autoInstanceFollowing", UNSET)

        abuse_state_change = d.pop("abuseStateChange", UNSET)

        abuse_new_message = d.pop("abuseNewMessage", UNSET)

        new_peer_tube_version = d.pop("newPeerTubeVersion", UNSET)

        new_plugin_version = d.pop("newPluginVersion", UNSET)

        my_video_studio_edition_finished = d.pop("myVideoStudioEditionFinished", UNSET)

        my_video_transcription_generated = d.pop("myVideoTranscriptionGenerated", UNSET)

        put_api_v1_users_me_notification_settings_body = cls(
            abuse_as_moderator=abuse_as_moderator,
            video_auto_blacklist_as_moderator=video_auto_blacklist_as_moderator,
            new_user_registration=new_user_registration,
            new_video_from_subscription=new_video_from_subscription,
            blacklist_on_my_video=blacklist_on_my_video,
            my_video_published=my_video_published,
            my_video_import_finished=my_video_import_finished,
            comment_mention=comment_mention,
            new_comment_on_my_video=new_comment_on_my_video,
            new_follow=new_follow,
            new_instance_follower=new_instance_follower,
            auto_instance_following=auto_instance_following,
            abuse_state_change=abuse_state_change,
            abuse_new_message=abuse_new_message,
            new_peer_tube_version=new_peer_tube_version,
            new_plugin_version=new_plugin_version,
            my_video_studio_edition_finished=my_video_studio_edition_finished,
            my_video_transcription_generated=my_video_transcription_generated,
        )

        put_api_v1_users_me_notification_settings_body.additional_properties = d
        return put_api_v1_users_me_notification_settings_body

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class GetSyndicatedCommentsFormat(str, Enum):
    """GetSyndicatedCommentsFormat enumeration."""

    ATOM = "atom"
    ATOM1 = "atom1"
    JSON = "json"
    JSON1 = "json1"
    RSS = "rss"
    RSS2 = "rss2"
    XML = "xml"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.server_config_custom_import_videos_http import (
        ServerConfigCustomImportVideosHttp,
    )
    from peertube.models.server_config_custom_import_videos_torrent import (
        ServerConfigCustomImportVideosTorrent,
    )


T = TypeVar("T", bound="ServerConfigCustomImportVideos")


@_attrs_define
class ServerConfigCustomImportVideos:
    """Attributes:
    http (Union[Unset, ServerConfigCustomImportVideosHttp]):
    torrent (Union[Unset, ServerConfigCustomImportVideosTorrent]):
    """

    http: Union[Unset, "ServerConfigCustomImportVideosHttp"] = UNSET
    torrent: Union[Unset, "ServerConfigCustomImportVideosTorrent"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        http: Unset | dict[str, Any] = UNSET
        if not isinstance(self.http, Unset):
            http = self.http.to_dict()

        torrent: Unset | dict[str, Any] = UNSET
        if not isinstance(self.torrent, Unset):
            torrent = self.torrent.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if http is not UNSET:
            field_dict["http"] = http
        if torrent is not UNSET:
            field_dict["torrent"] = torrent

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.server_config_custom_import_videos_http import (
            ServerConfigCustomImportVideosHttp,
        )
        from peertube.models.server_config_custom_import_videos_torrent import (
            ServerConfigCustomImportVideosTorrent,
        )

        d = dict(src_dict)
        _http = d.pop("http", UNSET)
        http: Unset | ServerConfigCustomImportVideosHttp
        if isinstance(_http, Unset):
            http = UNSET
        else:
            http = ServerConfigCustomImportVideosHttp.from_dict(_http)

        _torrent = d.pop("torrent", UNSET)
        torrent: Unset | ServerConfigCustomImportVideosTorrent
        if isinstance(_torrent, Unset):
            torrent = UNSET
        else:
            torrent = ServerConfigCustomImportVideosTorrent.from_dict(_torrent)

        server_config_custom_import_videos = cls(http=http, torrent=torrent)

        server_config_custom_import_videos.additional_properties = d
        return server_config_custom_import_videos

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Tests for api_video_channels_channel_handle_video_playlists function."""

from peertube.api.video_playlists.api_video_channels_channel_handle_video_playlists import (  # noqa: E501
    sync,
)
from peertube.models.get_api_v1_video_channels_channel_handle_video_playlists_response_200 import (  # noqa: E501
    GetApiV1VideoChannelsChannelHandleVideoPlaylistsResponse200,
)
from peertube.types import UNSET


def test_api_video_channels_channel_handle_video_playlists_success(
    httpx_mock, client, sample_playlist_response_data
):
    """Test successful retrieval of channel playlists."""
    # Mock HTTP response
    httpx_mock.add_response(
        method="GET",
        url="https://test.peertube.example/api/v1/video-channels/test-channel/video-playlists?count=15",
        json=sample_playlist_response_data,
        status_code=200,
    )

    # Test the function
    result = sync(
        channel_handle="test-channel",
        client=client,
        start=UNSET,
        count=15,
        sort=UNSET,
        playlist_type=UNSET,
    )

    # Assert result is the expected model
    expected = GetApiV1VideoChannelsChannelHandleVideoPlaylistsResponse200.from_dict(
        sample_playlist_response_data
    )
    assert result == expected



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.post_api_v1_runners_jobs_job_uuid_update_body_payload_type_0 import (
        PostApiV1RunnersJobsJobUUIDUpdateBodyPayloadType0,
    )


T = TypeVar("T", bound="PostApiV1RunnersJobsJobUUIDUpdateBody")


@_attrs_define
class PostApiV1RunnersJobsJobUUIDUpdateBody:
    """Attributes:
    runner_token (str):
    job_token (str):
    progress (Union[Unset, int]): Update job progression percentage (optional)
    payload (Union['PostApiV1RunnersJobsJobUUIDUpdateBodyPayloadType0', Unset]):
    """

    runner_token: str
    job_token: str
    progress: Unset | int = UNSET
    payload: Union["PostApiV1RunnersJobsJobUUIDUpdateBodyPayloadType0", Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        runner_token = self.runner_token

        job_token = self.job_token

        progress = self.progress

        payload: Unset | dict[str, Any]
        if isinstance(self.payload, Unset):
            payload = UNSET
        else:
            payload = self.payload.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "runnerToken": runner_token,
                "jobToken": job_token,
            }
        )
        if progress is not UNSET:
            field_dict["progress"] = progress
        if payload is not UNSET:
            field_dict["payload"] = payload

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.post_api_v1_runners_jobs_job_uuid_update_body_payload_type_0 import (
            PostApiV1RunnersJobsJobUUIDUpdateBodyPayloadType0,
        )

        d = dict(src_dict)
        runner_token = d.pop("runnerToken")

        job_token = d.pop("jobToken")

        progress = d.pop("progress", UNSET)

        def _parse_payload(
            data: object,
        ) -> Union["PostApiV1RunnersJobsJobUUIDUpdateBodyPayloadType0", Unset]:
            if isinstance(data, Unset):
                return data
            if not isinstance(data, dict):
                raise TypeError
            payload_type_0 = (
                PostApiV1RunnersJobsJobUUIDUpdateBodyPayloadType0.from_dict(data)
            )

            return payload_type_0

        payload = _parse_payload(d.pop("payload", UNSET))

        post_api_v1_runners_jobs_job_uuid_update_body = cls(
            runner_token=runner_token,
            job_token=job_token,
            progress=progress,
            payload=payload,
        )

        post_api_v1_runners_jobs_job_uuid_update_body.additional_properties = d
        return post_api_v1_runners_jobs_job_uuid_update_body

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any

from peertube.api.base.endpoint_base import BaseEndpoint
from peertube.client import AuthenticatedClient, Client
from peertube.models.get_account_videos_include import GetAccountVideosInclude
from peertube.models.get_account_videos_nsfw import GetAccountVideosNsfw
from peertube.models.get_account_videos_skip_count import GetAccountVideosSkipCount
from peertube.models.get_account_videos_sort import GetAccountVideosSort
from peertube.models.nsfw_flag import NSFWFlag
from peertube.models.video_list_response import VideoListResponse
from peertube.models.video_privacy_set import VideoPrivacySet
from peertube.types import UNSET, Response, Unset


class GetAccountVideosEndpoint(BaseEndpoint):
    """Endpoint for getting videos of an account."""

    @property
    def path(self) -> str:
        """API path for the endpoint."""
        return "/api/v1/accounts/{name}/videos"

    @property
    def method(self) -> str:
        """HTTP method for the endpoint."""
        return "get"

    @property
    def response_model(self) -> type[VideoListResponse] | None:
        """Response model class."""
        return VideoListResponse

    def _get_kwargs(self, *args: Any, **kwargs: Any) -> dict[str, Any]:
        """Build request kwargs with parameter processing."""
        name = args[0]  # First positional argument

        # Map parameter names to API parameter names
        param_mapping = {
            "start": "start",
            "count": "count",
            "skipCount": "skip_count",
            "sort": "sort",
            "nsfw": "nsfw",
            "nsfwFlagsIncluded": "nsfw_flags_included",
            "nsfwFlagsExcluded": "nsfw_flags_excluded",
            "isLive": "is_live",
            "includeScheduledLive": "include_scheduled_live",
            "categoryOneOf": "category_one_of",
            "licenceOneOf": "licence_one_of",
            "languageOneOf": "language_one_of",
            "tagsOneOf": "tags_one_of",
            "tagsAllOf": "tags_all_of",
            "isLocal": "is_local",
            "include": "include",
            "hasHLSFiles": "has_hls_files",
            "hasWebVideoFiles": "has_web_video_files",
            "host": "host",
            "autoTagOneOf": "auto_tag_one_of",
            "privacyOneOf": "privacy_one_of",
            "excludeAlreadyWatched": "exclude_already_watched",
            "search": "search",
        }

        # Build params dict with proper mapping
        params = {}
        for api_param, kwarg_name in param_mapping.items():
            if kwarg_name in kwargs:
                value = kwargs[kwarg_name]
                if hasattr(value, "value"):
                    params[api_param] = value.value
                else:
                    params[api_param] = value

        # Filter out UNSET and None values
        params = {k: v for k, v in params.items() if v is not Unset and v is not None}

        return {
            "method": self.method,
            "url": self.path.format(name=name),
            "params": params,
        }


# Backward compatibility functions
def sync_detailed(
    name: str,
    *,
    client: AuthenticatedClient | Client,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset | GetAccountVideosSkipCount = GetAccountVideosSkipCount.FALSE,
    sort: Unset | GetAccountVideosSort = UNSET,
    nsfw: Unset | GetAccountVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | GetAccountVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    search: Unset | str = UNSET,
) -> Response[VideoListResponse]:
    """List videos of an account

    Args:
        name: The account name.
        client: The HTTP client instance.
        start: Starting index for pagination.
        count: Number of items per page. Default: 15.
        skip_count: Whether to skip count. Default: GetAccountVideosSkipCount.FALSE.
        sort: Sort videos by criteria.
        nsfw: NSFW parameter.
        nsfw_flags_included: NSFW flags to include.
        nsfw_flags_excluded: NSFW flags to exclude.
        is_live: Whether videos are live.
        include_scheduled_live: Whether to include scheduled live videos.
        category_one_of: Category filter.
        licence_one_of: Licence filter.
        language_one_of: Language filter.
        tags_one_of: Tags filter (one of).
        tags_all_of: Tags filter (all of).
        is_local: Whether videos are local.
        include: What to include.
        has_hls_files: Whether videos have HLS files.
        has_web_video_files: Whether videos have web video files.
        host: Host filter.
        auto_tag_one_of: Auto tags filter.
        privacy_one_of: Privacy filter.
        exclude_already_watched: Whether to exclude already watched videos.
        search: Search query.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[VideoListResponse]
    """
    endpoint = GetAccountVideosEndpoint()
    return endpoint.sync_detailed(
        name,
        client=client,
        start=start,
        count=count,
        skip_count=skip_count,
        sort=sort,
        nsfw=nsfw,
        nsfw_flags_included=nsfw_flags_included,
        nsfw_flags_excluded=nsfw_flags_excluded,
        is_live=is_live,
        include_scheduled_live=include_scheduled_live,
        category_one_of=category_one_of,
        licence_one_of=licence_one_of,
        language_one_of=language_one_of,
        tags_one_of=tags_one_of,
        tags_all_of=tags_all_of,
        is_local=is_local,
        include=include,
        has_hls_files=has_hls_files,
        has_web_video_files=has_web_video_files,
        host=host,
        auto_tag_one_of=auto_tag_one_of,
        privacy_one_of=privacy_one_of,
        exclude_already_watched=exclude_already_watched,
        search=search,
    )


def sync(
    name: str,
    *,
    client: AuthenticatedClient | Client,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset | GetAccountVideosSkipCount = GetAccountVideosSkipCount.FALSE,
    sort: Unset | GetAccountVideosSort = UNSET,
    nsfw: Unset | GetAccountVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | GetAccountVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    search: Unset | str = UNSET,
) -> VideoListResponse | None:
    """List videos of an account

    Args:
        name: The account name.
        client: The HTTP client instance.
        start: Starting index for pagination.
        count: Number of items per page. Default: 15.
        skip_count: Whether to skip count. Default: GetAccountVideosSkipCount.FALSE.
        sort: Sort videos by criteria.
        nsfw: NSFW parameter.
        nsfw_flags_included: NSFW flags to include.
        nsfw_flags_excluded: NSFW flags to exclude.
        is_live: Whether videos are live.
        include_scheduled_live: Whether to include scheduled live videos.
        category_one_of: Category filter.
        licence_one_of: Licence filter.
        language_one_of: Language filter.
        tags_one_of: Tags filter (one of).
        tags_all_of: Tags filter (all of).
        is_local: Whether videos are local.
        include: What to include.
        has_hls_files: Whether videos have HLS files.
        has_web_video_files: Whether videos have web video files.
        host: Host filter.
        auto_tag_one_of: Auto tags filter.
        privacy_one_of: Privacy filter.
        exclude_already_watched: Whether to exclude already watched videos.
        search: Search query.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        VideoListResponse | None
    """
    endpoint = GetAccountVideosEndpoint()
    return endpoint.sync(
        name,
        client=client,
        start=start,
        count=count,
        skip_count=skip_count,
        sort=sort,
        nsfw=nsfw,
        nsfw_flags_included=nsfw_flags_included,
        nsfw_flags_excluded=nsfw_flags_excluded,
        is_live=is_live,
        include_scheduled_live=include_scheduled_live,
        category_one_of=category_one_of,
        licence_one_of=licence_one_of,
        language_one_of=language_one_of,
        tags_one_of=tags_one_of,
        tags_all_of=tags_all_of,
        is_local=is_local,
        include=include,
        has_hls_files=has_hls_files,
        has_web_video_files=has_web_video_files,
        host=host,
        auto_tag_one_of=auto_tag_one_of,
        privacy_one_of=privacy_one_of,
        exclude_already_watched=exclude_already_watched,
        search=search,
    )


async def asyncio_detailed(
    name: str,
    *,
    client: AuthenticatedClient | Client,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset | GetAccountVideosSkipCount = GetAccountVideosSkipCount.FALSE,
    sort: Unset | GetAccountVideosSort = UNSET,
    nsfw: Unset | GetAccountVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | GetAccountVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    search: Unset | str = UNSET,
) -> Response[VideoListResponse]:
    """List videos of an account

    Args:
        name: The account name.
        client: The HTTP client instance.
        start: Starting index for pagination.
        count: Number of items per page. Default: 15.
        skip_count: Whether to skip count. Default: GetAccountVideosSkipCount.FALSE.
        sort: Sort videos by criteria.
        nsfw: NSFW parameter.
        nsfw_flags_included: NSFW flags to include.
        nsfw_flags_excluded: NSFW flags to exclude.
        is_live: Whether videos are live.
        include_scheduled_live: Whether to include scheduled live videos.
        category_one_of: Category filter.
        licence_one_of: Licence filter.
        language_one_of: Language filter.
        tags_one_of: Tags filter (one of).
        tags_all_of: Tags filter (all of).
        is_local: Whether videos are local.
        include: What to include.
        has_hls_files: Whether videos have HLS files.
        has_web_video_files: Whether videos have web video files.
        host: Host filter.
        auto_tag_one_of: Auto tags filter.
        privacy_one_of: Privacy filter.
        exclude_already_watched: Whether to exclude already watched videos.
        search: Search query.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[VideoListResponse]
    """
    endpoint = GetAccountVideosEndpoint()
    return await endpoint.asyncio_detailed(
        name,
        client=client,
        start=start,
        count=count,
        skip_count=skip_count,
        sort=sort,
        nsfw=nsfw,
        nsfw_flags_included=nsfw_flags_included,
        nsfw_flags_excluded=nsfw_flags_excluded,
        is_live=is_live,
        include_scheduled_live=include_scheduled_live,
        category_one_of=category_one_of,
        licence_one_of=licence_one_of,
        language_one_of=language_one_of,
        tags_one_of=tags_one_of,
        tags_all_of=tags_all_of,
        is_local=is_local,
        include=include,
        has_hls_files=has_hls_files,
        has_web_video_files=has_web_video_files,
        host=host,
        auto_tag_one_of=auto_tag_one_of,
        privacy_one_of=privacy_one_of,
        exclude_already_watched=exclude_already_watched,
        search=search,
    )


async def asyncio(
    name: str,
    *,
    client: AuthenticatedClient | Client,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset | GetAccountVideosSkipCount = GetAccountVideosSkipCount.FALSE,
    sort: Unset | GetAccountVideosSort = UNSET,
    nsfw: Unset | GetAccountVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | GetAccountVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    search: Unset | str = UNSET,
) -> VideoListResponse | None:
    """List videos of an account

    Args:
        name: The account name.
        client: The HTTP client instance.
        start: Starting index for pagination.
        count: Number of items per page. Default: 15.
        skip_count: Whether to skip count. Default: GetAccountVideosSkipCount.FALSE.
        sort: Sort videos by criteria.
        nsfw: NSFW parameter.
        nsfw_flags_included: NSFW flags to include.
        nsfw_flags_excluded: NSFW flags to exclude.
        is_live: Whether videos are live.
        include_scheduled_live: Whether to include scheduled live videos.
        category_one_of: Category filter.
        licence_one_of: Licence filter.
        language_one_of: Language filter.
        tags_one_of: Tags filter (one of).
        tags_all_of: Tags filter (all of).
        is_local: Whether videos are local.
        include: What to include.
        has_hls_files: Whether videos have HLS files.
        has_web_video_files: Whether videos have web video files.
        host: Host filter.
        auto_tag_one_of: Auto tags filter.
        privacy_one_of: Privacy filter.
        exclude_already_watched: Whether to exclude already watched videos.
        search: Search query.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        VideoListResponse | None
    """
    endpoint = GetAccountVideosEndpoint()
    return await endpoint.asyncio(
        name,
        client=client,
        start=start,
        count=count,
        skip_count=skip_count,
        sort=sort,
        nsfw=nsfw,
        nsfw_flags_included=nsfw_flags_included,
        nsfw_flags_excluded=nsfw_flags_excluded,
        is_live=is_live,
        include_scheduled_live=include_scheduled_live,
        category_one_of=category_one_of,
        licence_one_of=licence_one_of,
        language_one_of=language_one_of,
        tags_one_of=tags_one_of,
        tags_all_of=tags_all_of,
        is_local=is_local,
        include=include,
        has_hls_files=has_hls_files,
        has_web_video_files=has_web_video_files,
        host=host,
        auto_tag_one_of=auto_tag_one_of,
        privacy_one_of=privacy_one_of,
        exclude_already_watched=exclude_already_watched,
        search=search,
    )



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from typing_extensions import Self

T = TypeVar("T", bound="UpdatePluginBodyType0")


@_attrs_define
class UpdatePluginBodyType0:
    """Attributes:
    npm_name (str):  Example: peertube-plugin-auth-ldap.
    """

    npm_name: str

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        npm_name = self.npm_name

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "npmName": npm_name,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        npm_name = d.pop("npmName")

        update_plugin_body_type_0 = cls(npm_name=npm_name)

        return update_plugin_body_type_0



from enum import IntEnum


class NSFWFlag(IntEnum):
    """NSFWFlag class."""

    VALUE_0 = 0
    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_4 = 4

    def __str__(self) -> str:
        return str(self.value)



"""Tests for mirrored_videos function."""

from peertube.api.video_mirroring.mirrored_videos import sync
from peertube.models.get_mirrored_videos_target import GetMirroredVideosTarget


def test_mirrored_videos_success(httpx_mock, auth_client):
    """Test successful retrieval of mirrored videos."""
    # Sample response data
    sample_data = [
        {
            "id": 3,
            "name": "Mirrored Video 1",
            "url": "https://example.com/mirrored1",
            "uuid": "7a7ae5e6-0a1e-484a-b099-e80766180a6b",
        },
    ]

    # Mock HTTP response
    httpx_mock.add_response(
        method="GET",
        url="https://test.peertube.example/api/v1/server/redundancy/videos?target=remote-videos&count=15",
        status_code=200,
        json=sample_data,
    )

    # Test the function
    result = sync(client=auth_client, target=GetMirroredVideosTarget.REMOTE_VIDEOS)

    assert result is not None
    assert len(result) == 1
    assert result[0].id == 3
    assert result[0].name == "Mirrored Video 1"



"""Tests for api_videos_id_passwords function."""

from peertube.api.video_passwords.api_videos_id_passwords import sync
from peertube.models.video_password_list import VideoPasswordList
from peertube.types import UNSET


def test_api_videos_id_passwords_success(httpx_mock, auth_client):
    """Test successful retrieval of video passwords."""
    # Mock response data
    response_data = {
        "total": 1,
        "data": [
            {
                "id": 123,
                "label": "Test Password",
                "createdAt": "2023-01-01T00:00:00.000Z",
            }
        ],
    }

    # Mock HTTP response
    httpx_mock.add_response(
        method="GET",
        url="https://test.peertube.example/api/v1/videos/123/passwords?count=15",
        json=response_data,
        status_code=200,
    )

    # Test the function
    result = sync(
        id=123,
        client=auth_client,
        start=UNSET,
        count=15,
        sort=UNSET,
    )

    # Assert result is the expected model
    expected = VideoPasswordList.from_dict(response_data)
    assert result == expected



#!/usr/bin/env python3
"""Generate OpenAPI client from PeerTube OpenAPI specification.

This script generates a Python client from the PeerTube OpenAPI specification
using openapi-python-client.
"""

import subprocess
import sys
from pathlib import Path


def generate_client() -> bool:
    """Generate the OpenAPI client from the specification."""

    repo_root = Path(__file__).parent.parent
    openapi_file = repo_root / "assets" / "openapi.json"
    output_dir = repo_root / "src" / "peertube" / "generated_client"

    if not openapi_file.exists():
        msg = f"OpenAPI specification not found at {openapi_file}"
        raise FileNotFoundError(msg)

    # Command to generate the client
    cmd = [
        "openapi-python-client",
        "generate",
        "--path",
        str(openapi_file),
        "--output-path",
        str(output_dir),
        "--config",
        str(repo_root / "openapi-client-config.yaml"),
    ]

    try:
        result = subprocess.run(cmd, check=True, capture_output=True, text=True)
        print(f"Generated client successfully:\n{result.stdout}")
    except subprocess.CalledProcessError as e:
        print(f"Failed to generate client:\n{e.stderr}")
        return False
    except FileNotFoundError:
        print("openapi-python-client not found. Install it with:")
        print("pip install openapi-python-client")
        return False
    else:
        return True


if __name__ == "__main__":
    success = generate_client()
    sys.exit(0 if success else 1)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.models.follow_state import FollowState
from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.actor import Actor


T = TypeVar("T", bound="Follow")


@_attrs_define
class Follow:
    """Attributes:
    id (Union[Unset, int]):  Example: 42.
    follower (Union[Unset, Actor]):
    following (Union[Unset, Actor]):
    score (Union[Unset, float]): score reflecting the reachability of the actor, with steps of `10` and a base score
        of `1000`.
    state (Union[Unset, FollowState]):
    created_at (Union[Unset, datetime.datetime]):
    updated_at (Union[Unset, datetime.datetime]):
    """

    id: Unset | int = UNSET
    follower: Union[Unset, "Actor"] = UNSET
    following: Union[Unset, "Actor"] = UNSET
    score: Unset | float = UNSET
    state: Unset | FollowState = UNSET
    created_at: Unset | datetime.datetime = UNSET
    updated_at: Unset | datetime.datetime = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        id = self.id

        follower: Unset | dict[str, Any] = UNSET
        if not isinstance(self.follower, Unset):
            follower = self.follower.to_dict()

        following: Unset | dict[str, Any] = UNSET
        if not isinstance(self.following, Unset):
            following = self.following.to_dict()

        score = self.score

        state: Unset | str = UNSET
        if not isinstance(self.state, Unset):
            state = self.state.value

        created_at: Unset | str = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Unset | str = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if follower is not UNSET:
            field_dict["follower"] = follower
        if following is not UNSET:
            field_dict["following"] = following
        if score is not UNSET:
            field_dict["score"] = score
        if state is not UNSET:
            field_dict["state"] = state
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.actor import Actor

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        _follower = d.pop("follower", UNSET)
        follower: Unset | Actor
        if isinstance(_follower, Unset):
            follower = UNSET
        else:
            follower = Actor.from_dict(_follower)

        _following = d.pop("following", UNSET)
        following: Unset | Actor
        if isinstance(_following, Unset):
            following = UNSET
        else:
            following = Actor.from_dict(_following)

        score = d.pop("score", UNSET)

        _state = d.pop("state", UNSET)
        state: Unset | FollowState
        if isinstance(_state, Unset):
            state = UNSET
        else:
            state = FollowState(_state)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Unset | datetime.datetime
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Unset | datetime.datetime
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        follow = cls(
            id=id,
            follower=follower,
            following=following,
            score=score,
            state=state,
            created_at=created_at,
            updated_at=updated_at,
        )

        follow.additional_properties = d
        return follow

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from io import BytesIO
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.types import UNSET, File, FileTypes, Unset

if TYPE_CHECKING:
    from peertube.models.video import Video
    from peertube.models.video_import_state_constant import VideoImportStateConstant


T = TypeVar("T", bound="VideoImport")


@_attrs_define
class VideoImport:
    """Attributes:
    id (Union[Unset, int]):  Example: 42.
    target_url (Union[Unset, str]): remote URL where to find the import's source video Example:
        https://framatube.org/videos/watch/9c9de5e8-0a1e-484a-b099-e80766180a6d.
    magnet_uri (Union[Unset, str]): magnet URI allowing to resolve the import's source video
    torrentfile (Union[Unset, File]): Torrent file containing only the video file
    torrent_name (Union[Unset, str]):
    state (Union[Unset, VideoImportStateConstant]):
    error (Union[Unset, str]):
    created_at (Union[Unset, datetime.datetime]):
    updated_at (Union[Unset, datetime.datetime]):
    video (Union['Video', None, Unset]):
    """

    id: Unset | int = UNSET
    target_url: Unset | str = UNSET
    magnet_uri: Unset | str = UNSET
    torrentfile: Unset | File = UNSET
    torrent_name: Unset | str = UNSET
    state: Union[Unset, "VideoImportStateConstant"] = UNSET
    error: Unset | str = UNSET
    created_at: Unset | datetime.datetime = UNSET
    updated_at: Unset | datetime.datetime = UNSET
    video: Union["Video", None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        from peertube.models.video import Video

        id = self.id

        target_url = self.target_url

        magnet_uri = self.magnet_uri

        torrentfile: Unset | FileTypes = UNSET
        if not isinstance(self.torrentfile, Unset):
            torrentfile = self.torrentfile.to_tuple()

        torrent_name = self.torrent_name

        state: Unset | dict[str, Any] = UNSET
        if not isinstance(self.state, Unset):
            state = self.state.to_dict()

        error = self.error

        created_at: Unset | str = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Unset | str = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        video: None | Unset | dict[str, Any]
        if isinstance(self.video, Unset):
            video = UNSET
        elif isinstance(self.video, Video):
            video = self.video.to_dict()
        else:
            video = self.video

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if target_url is not UNSET:
            field_dict["targetUrl"] = target_url
        if magnet_uri is not UNSET:
            field_dict["magnetUri"] = magnet_uri
        if torrentfile is not UNSET:
            field_dict["torrentfile"] = torrentfile
        if torrent_name is not UNSET:
            field_dict["torrentName"] = torrent_name
        if state is not UNSET:
            field_dict["state"] = state
        if error is not UNSET:
            field_dict["error"] = error
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at
        if video is not UNSET:
            field_dict["video"] = video

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.video import Video
        from peertube.models.video_import_state_constant import VideoImportStateConstant

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        target_url = d.pop("targetUrl", UNSET)

        magnet_uri = d.pop("magnetUri", UNSET)

        _torrentfile = d.pop("torrentfile", UNSET)
        torrentfile: Unset | File
        if isinstance(_torrentfile, Unset):
            torrentfile = UNSET
        else:
            torrentfile = File(payload=BytesIO(_torrentfile))

        torrent_name = d.pop("torrentName", UNSET)

        _state = d.pop("state", UNSET)
        state: Unset | VideoImportStateConstant
        if isinstance(_state, Unset):
            state = UNSET
        else:
            state = VideoImportStateConstant.from_dict(_state)

        error = d.pop("error", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Unset | datetime.datetime
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Unset | datetime.datetime
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        def _parse_video(data: object) -> Union["Video", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError
                video_type_1 = Video.from_dict(data)

                return video_type_1
            except:  # noqa: E722
                pass
            return cast("Video | None | Unset", data)

        video = _parse_video(d.pop("video", UNSET))

        video_import = cls(
            id=id,
            target_url=target_url,
            magnet_uri=magnet_uri,
            torrentfile=torrentfile,
            torrent_name=torrent_name,
            state=state,
            error=error,
            created_at=created_at,
            updated_at=updated_at,
            video=video,
        )

        video_import.additional_properties = d
        return video_import

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.models.runner_job_type import RunnerJobType
from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.runner_job_state_constant import RunnerJobStateConstant


T = TypeVar("T", bound="RunnerJobParentType0")


@_attrs_define
class RunnerJobParentType0:
    """If job has a parent job

    Attributes:
        type_ (Union[Unset, RunnerJobType]):
        state (Union[Unset, RunnerJobStateConstant]):
        uuid (Union[Unset, UUID]):  Example: 9c9de5e8-0a1e-484a-b099-e80766180a6d.
    """

    type_: Unset | RunnerJobType = UNSET
    state: Union[Unset, "RunnerJobStateConstant"] = UNSET
    uuid: Unset | UUID = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        type_: Unset | str = UNSET
        if not isinstance(self.type_, Unset):
            type_ = self.type_.value

        state: Unset | dict[str, Any] = UNSET
        if not isinstance(self.state, Unset):
            state = self.state.to_dict()

        uuid: Unset | str = UNSET
        if not isinstance(self.uuid, Unset):
            uuid = str(self.uuid)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if type_ is not UNSET:
            field_dict["type"] = type_
        if state is not UNSET:
            field_dict["state"] = state
        if uuid is not UNSET:
            field_dict["uuid"] = uuid

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.runner_job_state_constant import RunnerJobStateConstant

        d = dict(src_dict)
        _type_ = d.pop("type", UNSET)
        type_: Unset | RunnerJobType
        if isinstance(_type_, Unset):
            type_ = UNSET
        else:
            type_ = RunnerJobType(_type_)

        _state = d.pop("state", UNSET)
        state: Unset | RunnerJobStateConstant
        if isinstance(_state, Unset):
            state = UNSET
        else:
            state = RunnerJobStateConstant.from_dict(_state)

        _uuid = d.pop("uuid", UNSET)
        uuid: Unset | UUID
        if isinstance(_uuid, Unset):
            uuid = UNSET
        else:
            uuid = UUID(_uuid)

        runner_job_parent_type_0 = cls(type_=type_, state=state, uuid=uuid)

        runner_job_parent_type_0.additional_properties = d
        return runner_job_parent_type_0

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
